@@ -37,18 +37,27 @@
 #include "gtr-io-error-info-bar.h"
 #include "gtr-message-table.h"
 #include "gtr-msg.h"
+#include "gtr-tab-activatable.h"
 #include "gtr-tab.h"
 #include "gtr-po.h"
 #include "gtr-settings.h"
 #include "gtr-view.h"
 #include "gtr-translation-memory.h"
 #include "gtr-translation-memory-ui.h"
-#include "gtr-window.h"
+#include "gtr-dirs.h"
+#include "gtr-plugins-engine.h"
 
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <libpeas/peas-extension-set.h>
+
+#ifdef G_OS_WIN32
+#include <gdl/libgdltypebuiltins.h>
+#else
+#include <gdl/gdl.h>
+#endif
 
 #define GTR_TAB_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ( \
 					 (object),	\
@@ -63,18 +72,17 @@ G_DEFINE_TYPE (GtrTab, gtr_tab, GTK_TYPE_VBOX)
 
 struct _GtrTabPrivate
 {
+  GSettings *ui_settings;
   GSettings *files_settings;
   GSettings *editor_settings;
   GSettings *state_settings;
 
   GtrPo *po;
 
-  GtkWidget *table_pane;
-  GtkWidget *content_pane;
-  GtkWidget *message_table;
-  GtkWidget *lateral_panel;        //TM, Context, etc.
+  GtkWidget *dock;
+  GdlDockLayout *layout_manager;
 
-  GtkWidget *context_pane;
+  GtkWidget *message_table;
   GtkWidget *context;
   GtkWidget *translation_memory;
 
@@ -99,6 +107,8 @@ struct _GtrTabPrivate
   GtkWidget *fuzzy;
   GtkWidget *untranslated;
 
+  PeasExtensionSet *extensions;
+
   /* Autosave */
   GTimer *timer;
   gint autosave_interval;
@@ -107,6 +117,8 @@ struct _GtrTabPrivate
 
   /*Blocking movement */
   guint blocking : 1;
+
+  guint tab_realized : 1;
 };
 
 enum
@@ -129,6 +141,104 @@ static guint signals[LAST_SIGNAL];
 
 static gboolean gtr_tab_autosave (GtrTab * tab);
 
+static void
+gtr_tab_layout_save (GtrTab      *tab,
+                     const gchar *filename,
+                     const gchar *name)
+{
+  g_return_if_fail (GTR_IS_TAB (tab));
+  g_return_if_fail (filename != NULL);
+
+  gdl_dock_layout_save_layout (tab->priv->layout_manager, name);
+  if (!gdl_dock_layout_save_to_file (tab->priv->layout_manager, filename))
+    g_warning ("Saving dock layout to '%s' failed!", filename);
+}
+
+static void
+gtr_tab_layout_load (GtrTab      *tab,
+                     const gchar *layout_filename,
+                     const gchar *name)
+{
+  g_return_if_fail (GTR_IS_TAB (tab));
+
+  if (!layout_filename ||
+      !gdl_dock_layout_load_from_file (tab->priv->layout_manager,
+                                       layout_filename))
+    {
+      gchar *path;
+
+      path = gtr_dirs_get_ui_file ("layout.xml");
+
+      if (!gdl_dock_layout_load_from_file (tab->priv->layout_manager,
+                                           path))
+        g_warning ("Loading layout from '%s' failed!!", path);
+      g_free (path);
+    }
+
+  if (!gdl_dock_layout_load_layout (tab->priv->layout_manager, name))
+    g_warning ("Loading layout failed!!");
+}
+
+static void
+add_widget_to_dock (GtrTab      *tab,
+                    GtkWidget   *widget,
+                    const gchar *name,
+                    const gchar *title,
+                    const gchar *stock_id,
+                    GtrTabPlacement placement,
+                    gboolean locked)
+{
+  GtkWidget *item;
+  guint flags = 0;
+
+  g_return_if_fail (GTR_IS_TAB (tab));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (name != NULL);
+  g_return_if_fail (title != NULL);
+
+  /* Add the widget to dock */
+  if (stock_id == NULL)
+    item = gdl_dock_item_new (name, title, GDL_DOCK_ITEM_BEH_NORMAL);
+  else
+    item = gdl_dock_item_new_with_stock (name, title, stock_id,
+                                         GDL_DOCK_ITEM_BEH_NORMAL);
+
+  if (locked)
+    {
+      flags |= GDL_DOCK_ITEM_BEH_NO_GRIP;
+    }
+
+  flags |= GDL_DOCK_ITEM_BEH_CANT_CLOSE |
+           GDL_DOCK_ITEM_BEH_CANT_ICONIFY |
+           GDL_DOCK_ITEM_BEH_NEVER_FLOATING;
+  g_object_set (G_OBJECT (item), "behavior", flags, NULL);
+
+  gtk_container_add (GTK_CONTAINER (item), widget);
+  gdl_dock_add_item (GDL_DOCK (tab->priv->dock),
+                     GDL_DOCK_ITEM (item), placement);
+  gtk_widget_show (item);
+
+  /* To remove it */
+  g_object_set_data (G_OBJECT (widget), "dockitem", item);
+}
+
+static void
+remove_widget_from_dock (GtrTab    *tab,
+                         GtkWidget *widget)
+{
+  GtkWidget *dock_item;
+
+  g_return_if_fail (GTR_IS_TAB (tab));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  dock_item = g_object_get_data (G_OBJECT (widget), "dockitem");
+  g_return_if_fail (dock_item != NULL);
+
+  /* Remove the widget from container */
+  gtk_container_remove (GTK_CONTAINER (dock_item), widget);
+  gdl_dock_item_unbind (GDL_DOCK_ITEM (dock_item));
+}
+
 static void
 install_autosave_timeout (GtrTab * tab)
 {
@@ -193,12 +303,17 @@ gtr_tab_edition_finished (GtrTab * tab, GtrMsg * msg)
   GtrTranslationMemory *tm;
   gchar *message_error;
   GtkWidget *infobar;
+  GtrHeader *header;
 
-  tm =
-    GTR_TRANSLATION_MEMORY (gtr_application_get_translation_memory (GTR_APP));
+  header = gtr_po_get_header (tab->priv->po);
 
-  if (gtr_msg_is_translated (msg) && !gtr_msg_is_fuzzy (msg))
-    gtr_translation_memory_store (tm, msg);
+  if (gtr_header_get_profile (header) != NULL)
+    {
+      tm = GTR_TRANSLATION_MEMORY (gtr_application_get_translation_memory (GTR_APP));
+
+      if (gtr_msg_is_translated (msg) && !gtr_msg_is_fuzzy (msg))
+        gtr_translation_memory_store (tm, msg);
+    }
 
   /*
    * Checking message
@@ -551,29 +666,63 @@ on_state_notify (GtrPo      *po,
 }
 
 static void
-gtr_tab_draw (GtrTab * tab)
+on_layout_changed (GdlDockMaster *master,
+                   GtrTab        *tab)
 {
+  gchar *filename;
+
+  filename = g_build_filename (gtr_dirs_get_user_config_dir (),
+                               "gtr-layout.xml", NULL);
+
+  gtr_tab_layout_save (tab, filename, NULL);
+  g_free (filename);
+}
+
+static void
+gtr_tab_draw (GtrTab *tab)
+{
+  GtkWidget *hbox;
   GtkWidget *vertical_box;
-  GtkWidget *vcontext_box;
   GtkWidget *msgid_label;
   GtkWidget *scroll;
+  GtkWidget *dockbar;
   GtrTabPrivate *priv = tab->priv;
 
-  /* Content pane; this is where the message table and message area go */
-  priv->content_pane = gtk_vpaned_new ();
-  g_settings_bind (tab->priv->state_settings,
-                   GTR_SETTINGS_CONTENT_PANEL_SIZE,
-                   priv->content_pane,
-                   "position",
+  /* Docker */
+  hbox = gtk_hbox_new (FALSE, 0);
+  gtk_widget_show (hbox);
+  gtk_box_pack_start (GTK_BOX (tab), hbox, TRUE, TRUE, 0);
+
+  priv->dock = gdl_dock_new ();
+  gtk_widget_show (priv->dock);
+  gtk_box_pack_end (GTK_BOX (hbox), priv->dock, TRUE, TRUE, 0);
+
+  dockbar = gdl_dock_bar_new (GDL_DOCK (priv->dock));
+  gtk_widget_show (dockbar);
+  gtk_box_pack_start (GTK_BOX (hbox), dockbar, FALSE, FALSE, 0);
+
+  priv->layout_manager = gdl_dock_layout_new (GDL_DOCK (priv->dock));
+  g_signal_connect (priv->layout_manager->master,
+                    "layout-changed",
+                    G_CALLBACK (on_layout_changed),
+                    tab);
+
+  g_settings_bind (priv->ui_settings,
+                   GTR_SETTINGS_PANEL_SWITCHER_STYLE,
+                   priv->layout_manager->master,
+                   "switcher-style",
                    G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  gtk_widget_show (priv->content_pane);
 
   /* Message table */
   priv->message_table = gtr_message_table_new (GTK_WIDGET (tab));
   gtk_widget_show (priv->message_table);
 
-  gtk_paned_pack1 (GTK_PANED (priv->content_pane), GTK_WIDGET (priv->message_table),
-                   TRUE, FALSE);
+  add_widget_to_dock (tab, priv->message_table,
+                      "GtrMessageTable",
+                      _("Message Table"),
+                      NULL,
+                      GTR_TAB_PLACEMENT_CENTER,
+                      FALSE);
 
   /* Orignal text widgets */
   priv->msgid_hbox = gtk_hbox_new (FALSE, 0);
@@ -635,7 +784,6 @@ gtr_tab_draw (GtrTab * tab)
                       0);
   gtk_box_pack_start (GTK_BOX (vertical_box), priv->text_vbox, TRUE, TRUE, 0);
 
-
   /* Translation widgets */
   priv->msgstr_label = gtk_label_new (NULL);
   gtk_label_set_markup_with_mnemonic (GTK_LABEL (priv->msgstr_label),
@@ -653,44 +801,50 @@ gtr_tab_draw (GtrTab * tab)
   gtk_box_pack_start (GTK_BOX (vertical_box), priv->trans_notebook, TRUE,
                       TRUE, 0);
 
-  gtk_paned_pack2 (GTK_PANED (priv->content_pane), vertical_box, FALSE,
-                   TRUE);
-
-  /* Context pane */
-  priv->context_pane = gtk_hpaned_new ();
-  g_settings_bind (tab->priv->state_settings,
-                   GTR_SETTINGS_CONTEXT_PANEL_SIZE,
-                   priv->context_pane,
-                   "position",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-  gtk_widget_show (priv->context_pane);
-
-  gtk_paned_pack1 (GTK_PANED (priv->context_pane), priv->content_pane,
-                   FALSE, TRUE);
-  gtk_box_pack_start (GTK_BOX (tab), priv->context_pane, TRUE, TRUE, 0);
-
-  /* Vertical context box (TM, context etc ) */
-  vcontext_box = gtk_vbox_new (FALSE, 6);
-  gtk_widget_show (vcontext_box);
-  gtk_paned_pack2 (GTK_PANED (priv->context_pane), vcontext_box,
-                   TRUE, TRUE);
+  add_widget_to_dock (tab, vertical_box,
+                      "GtrTranslationFields",
+                      _("Translation Fields"),
+                      NULL,
+                      GTR_TAB_PLACEMENT_BOTTOM,
+                      TRUE);
 
   /* TM */
   priv->translation_memory = gtr_translation_memory_ui_new (GTK_WIDGET (tab));
   gtk_widget_show (priv->translation_memory);
-  gtk_box_pack_start (GTK_BOX (vcontext_box), priv->translation_memory,
-                      TRUE, TRUE, 0);
-
-  /* Lateral panel */
-  tab->priv->lateral_panel = gtk_notebook_new ();
-  gtk_widget_show (tab->priv->lateral_panel);
-  gtk_box_pack_start (GTK_BOX (vcontext_box), tab->priv->lateral_panel,
-                      TRUE, TRUE, 0);
+  add_widget_to_dock (tab, priv->translation_memory,
+                      "GtrTranslationMemoryUI",
+                      _("Translation Memory"),
+                      NULL,
+                      GTR_TAB_PLACEMENT_RIGHT,
+                      FALSE);
 
   /* Context */
   priv->context = gtr_context_panel_new (GTK_WIDGET (tab));
   gtk_widget_show (priv->context);
-  gtr_tab_add_widget_to_lateral_panel (tab, priv->context, _("Context"));
+  add_widget_to_dock (tab, priv->context,
+                      "GtrContextPanel",
+                      _("Context"),
+                      NULL,
+                      GTR_TAB_PLACEMENT_RIGHT,
+                      FALSE);
+}
+
+static void
+extension_added (PeasExtensionSet *extensions,
+                 PeasPluginInfo   *info,
+                 PeasExtension    *exten,
+                 GtrTab           *tab)
+{
+  peas_extension_call (exten, "activate");
+}
+
+static void
+extension_removed (PeasExtensionSet *extensions,
+                   PeasPluginInfo   *info,
+                   PeasExtension    *exten,
+                   GtrTab           *tab)
+{
+  peas_extension_call (exten, "deactivate");
 }
 
 static void
@@ -698,6 +852,7 @@ gtr_tab_init (GtrTab * tab)
 {
   tab->priv = GTR_TAB_GET_PRIVATE (tab);
 
+  tab->priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
   tab->priv->files_settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
   tab->priv->editor_settings = g_settings_new ("org.gnome.gtranslator.preferences.editor");
   tab->priv->state_settings = g_settings_new ("org.gnome.gtranslator.state.window");
@@ -715,6 +870,20 @@ gtr_tab_init (GtrTab * tab)
                                                      GTR_SETTINGS_AUTO_SAVE_INTERVAL);
   if (tab->priv->autosave_interval <= 0)
     tab->priv->autosave_interval = 1;
+
+  /* Plugins */
+  tab->priv->extensions = peas_extension_set_new (PEAS_ENGINE (gtr_plugins_engine_get_default ()),
+                                                  GTR_TYPE_TAB_ACTIVATABLE,
+                                                  "tab", tab,
+                                                  NULL);
+  g_signal_connect (tab->priv->extensions,
+                    "extension-added",
+                    G_CALLBACK (extension_added),
+                    tab);
+  g_signal_connect (tab->priv->extensions,
+                    "extension-removed",
+                    G_CALLBACK (extension_removed),
+                    tab);
 }
 
 static void
@@ -734,30 +903,48 @@ gtr_tab_finalize (GObject * object)
 static void
 gtr_tab_dispose (GObject * object)
 {
-  GtrTab *tab = GTR_TAB (object);
+  GtrTabPrivate *priv = GTR_TAB (object)->priv;
 
-  if (tab->priv->po != NULL)
+  if (priv->extensions != NULL)
     {
-      g_object_unref (tab->priv->po);
-      tab->priv->po = NULL;
+      g_object_unref (priv->extensions);
+      priv->extensions = NULL;
     }
 
-  if (tab->priv->files_settings != NULL)
+  if (priv->po != NULL)
     {
-      g_object_unref (tab->priv->files_settings);
-      tab->priv->files_settings = NULL;
+      g_object_unref (priv->po);
+      priv->po = NULL;
     }
 
-  if (tab->priv->editor_settings != NULL)
+  if (priv->ui_settings)
     {
-      g_object_unref (tab->priv->editor_settings);
-      tab->priv->editor_settings = NULL;
+      g_object_unref (priv->ui_settings);
+      priv->ui_settings = NULL;
     }
 
-  if (tab->priv->state_settings != NULL)
+  if (priv->files_settings != NULL)
     {
-      g_object_unref (tab->priv->state_settings);
-      tab->priv->state_settings = NULL;
+      g_object_unref (priv->files_settings);
+      priv->files_settings = NULL;
+    }
+
+  if (priv->editor_settings != NULL)
+    {
+      g_object_unref (priv->editor_settings);
+      priv->editor_settings = NULL;
+    }
+
+  if (priv->state_settings != NULL)
+    {
+      g_object_unref (priv->state_settings);
+      priv->state_settings = NULL;
+    }
+
+  if (priv->layout_manager)
+    {
+      g_object_unref (priv->layout_manager);
+      priv->layout_manager = NULL;
     }
 
   G_OBJECT_CLASS (gtr_tab_parent_class)->dispose (object);
@@ -803,10 +990,37 @@ gtr_tab_set_property (GObject * object,
     }
 }
 
+static void
+gtr_tab_realize (GtkWidget *widget)
+{
+  GtrTab *tab = GTR_TAB (widget);
+
+  GTK_WIDGET_CLASS (gtr_tab_parent_class)->realize (widget);
+
+  if (!tab->priv->tab_realized)
+    {
+      gchar *filename;
+
+      /* We only activate the extensions when the tab is realized,
+       * because most plugins will expect this behaviour. */
+      peas_extension_set_call (tab->priv->extensions, "activate");
+
+      /* Loading dock layout */
+      filename = g_build_filename (gtr_dirs_get_user_config_dir (),
+                                   "gtr-layout.xml", NULL);
+
+      gtr_tab_layout_load (tab, filename, NULL);
+      g_free (filename);
+
+      tab->priv->tab_realized = TRUE;
+    }
+}
+
 static void
 gtr_tab_class_init (GtrTabClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GtrTabPrivate));
 
@@ -814,6 +1028,9 @@ gtr_tab_class_init (GtrTabClass * klass)
   object_class->dispose = gtr_tab_dispose;
   object_class->set_property = gtr_tab_set_property;
   object_class->get_property = gtr_tab_get_property;
+
+  widget_class->realize = gtr_tab_realize;
+
   klass->message_edition_finished = gtr_tab_edition_finished;
 
   /* Signals */
@@ -920,7 +1137,7 @@ gtr_tab_new (GtrPo * po)
  * gtr_tab_get_po:
  * @tab: a #GtrTab
  *
- * Return value: the #GtrPo stored in the #GtrTab
+ * Return value: (transfer none): the #GtrPo stored in the #GtrTab
 **/
 GtrPo *
 gtr_tab_get_po (GtrTab * tab)
@@ -945,7 +1162,7 @@ gtr_tab_get_active_trans_tab (GtrTab * tab)
  * gtr_tab_get_context_panel:
  * @tab: a #GtrTab
  *
- * Return value: the #GtranslaorContextPanel
+ * Return value: (transfer none): the #GtranslaorContextPanel
  */
 GtrContextPanel *
 gtr_tab_get_context_panel (GtrTab * tab)
@@ -957,7 +1174,7 @@ gtr_tab_get_context_panel (GtrTab * tab)
  * gtr_tab_get_translation_memory_ui:
  * @tab: a #GtrTab
  *
- * Returns: the #GtrTranslationMemoryUi panel.
+ * Returns: (transfer none): the #GtrTranslationMemoryUi panel.
  */
 GtkWidget *
 gtr_tab_get_translation_memory_ui (GtrTab * tab)
@@ -971,7 +1188,7 @@ gtr_tab_get_translation_memory_ui (GtrTab * tab)
  * gtr_tab_get_active_view:
  * @tab: a #GtranslationTab
  *
- * Return value: the active page of the translation notebook.
+ * Return value: (transfer none): the active page of the translation notebook.
 **/
 GtrView *
 gtr_tab_get_active_view (GtrTab * tab)
@@ -991,7 +1208,7 @@ gtr_tab_get_active_view (GtrTab * tab)
  *
  * Returns all the views currently present in #GtranslationTab
  *
- * Return value: a newly allocated list of #GtranslationTab objects
+ * Return: (transfer container): a newly allocated list of #GtranslationTab objects
  */
 GList *
 gtr_tab_get_all_views (GtrTab * tab, gboolean original, gboolean translated)
@@ -1186,7 +1403,7 @@ _gtr_tab_can_close (GtrTab * tab)
  *
  * Returns the #GtrTab for a specific #GtrPo.
  *
- * Returns: the #GtrTab for a specific #GtrPo
+ * Returns: (transfer none): the #GtrTab for a specific #GtrPo
  */
 GtrTab *
 gtr_tab_get_from_document (GtrPo * po)
@@ -1300,66 +1517,75 @@ gtr_tab_set_autosave_interval (GtrTab * tab, gint interval)
 }
 
 /**
- * gtr_tab_add_widget_to_lateral_panel:
+ * gtr_tab_add_widget:
  * @tab: a #GtrTab
  * @widget: a #GtkWidget
- * @tab_name: the tab name in the notebook
+ * @unique_name: an unique name for the widget
+ * @name: the name of @widget
+ * @stock_id: (allow-none): stock id for the icon of @widget or %NULL
+ * @placement: where to place @widget in the tab
  *
- * Adds a new widget to the laberal panel notebook.
+ * Adds a new widget to place in @tab.
  */
 void
-gtr_tab_add_widget_to_lateral_panel (GtrTab * tab,
-                                     GtkWidget * widget,
-                                     const gchar * tab_name)
+gtr_tab_add_widget (GtrTab         *tab,
+                    GtkWidget      *widget,
+                    const gchar    *unique_name,
+                    const gchar    *name,
+                    const gchar    *stock_id,
+                    GtrTabPlacement placement)
 {
-  GtkWidget *label;
+  g_return_if_fail (GTR_IS_TAB (tab));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  add_widget_to_dock (tab, widget, unique_name, name, NULL, placement, FALSE);
+}
+
+/**
+ * gtr_tab_remove_widget:
+ * @tab: a #GtrTab
+ * @widget: a #GtkWidget
+ *
+ * Removes the @widget from @tab.
+ */
+void
+gtr_tab_remove_widget (GtrTab    *tab,
+                       GtkWidget *widget)
+{
+  g_return_if_fail (GTR_IS_TAB (tab));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  remove_widget_from_dock (tab, widget);
+}
+
+/**
+ * gtr_tab_show_widget:
+ * @tab: a #GtrTab
+ * @widget: a #GtkWidget
+ *
+ * Presents the widget if it is not visible
+ */
+void
+gtr_tab_show_widget (GtrTab    *tab,
+                     GtkWidget *widget)
+{
+  GtkWidget *item;
+  GtkWidget *parent;
 
   g_return_if_fail (GTR_IS_TAB (tab));
   g_return_if_fail (GTK_IS_WIDGET (widget));
 
-  label = gtk_label_new (tab_name);
+  item = g_object_get_data (G_OBJECT (widget), "dockitem");
+  g_return_if_fail (item != NULL);
 
-  gtk_notebook_append_page (GTK_NOTEBOOK (tab->priv->lateral_panel),
-                            widget, label);
-}
-
-/**
- * gtr_tab_remove_widget_from_lateral_panel:
- * @tab: a #GtrTab
- * @widget: a #GtkWidget
- *
- * Removes the @widget from the lateral panel notebook of @tab.
- */
-void
-gtr_tab_remove_widget_from_lateral_panel (GtrTab * tab, GtkWidget * widget)
-{
-  gint page;
-
-  g_return_if_fail (GTR_IS_TAB (tab));
-  g_return_if_fail (GTK_IS_WIDGET (widget));
-
-  page = gtk_notebook_page_num (GTK_NOTEBOOK (tab->priv->lateral_panel),
-                                widget);
-
-  gtk_notebook_remove_page (GTK_NOTEBOOK (tab->priv->lateral_panel), page);
-}
-
-/**
- * gtr_tab_show_lateral_panel_widget:
- * @tab: a #GtrTab
- * @widget: the widget to be shown.
- *
- * Shows the notebook page of the @widget.
- */
-void
-gtr_tab_show_lateral_panel_widget (GtrTab * tab, GtkWidget * widget)
-{
-  gint page;
-
-  page = gtk_notebook_page_num (GTK_NOTEBOOK (tab->priv->lateral_panel),
-                                widget);
-  gtk_notebook_set_current_page (GTK_NOTEBOOK (tab->priv->lateral_panel),
-                                 page);
+  /* FIXME: Hack to present the dock item if it's in a notebook dock item */
+  parent = gtk_widget_get_parent (GTK_WIDGET(item) );
+  if (GTK_IS_NOTEBOOK (parent))
+    {
+      gint pagenum;
+      pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (parent), item);
+      gtk_notebook_set_current_page (GTK_NOTEBOOK (parent), pagenum);
+    }
 }
 
 /**
@@ -1402,7 +1628,7 @@ gtr_tab_copy_to_translation (GtrTab * tab)
 {
   GtkTextBuffer *msgstr, *msgid;
   gint page_index;
-  const gchar *text;
+  gchar *text;
   GtkTextIter start, end;
 
   g_return_if_fail (GTR_IS_TAB (tab));
@@ -1418,6 +1644,7 @@ gtr_tab_copy_to_translation (GtrTab * tab)
   gtk_text_buffer_get_bounds (msgid, &start, &end);
   text = gtk_text_buffer_get_text (msgid, &start, &end, FALSE);
   gtk_text_buffer_set_text (msgstr, text, -1);
+  g_free (text);
   gtk_text_buffer_end_user_action (msgstr);
 }
 
