@@ -28,9 +28,10 @@
 #include <string.h>
 
 #include "gtr-dirs.h"
-#include "gtr-prefs-manager.h"
+#include "gtr-settings.h"
 #include "gtr-utils.h"
 #include "gtr-view.h"
+#include "gtr-application.h"
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -38,7 +39,6 @@
 #include <gtk/gtk.h>
 
 #include <gtksourceview/gtksourcelanguagemanager.h>
-#include <gtksourceview/gtksourceiter.h>
 #include <gtksourceview/gtksourcebuffer.h>
 #include <gtksourceview/gtksourcestyleschememanager.h>
 
@@ -51,10 +51,13 @@
 						 	GTR_TYPE_VIEW,     \
 						 	GtrViewPrivate))
 
-G_DEFINE_TYPE (GtrView, gtr_view, GTK_TYPE_SOURCE_VIEW)
+G_DEFINE_TYPE (GtrView, gtr_view, GTK_SOURCE_TYPE_VIEW)
 
 struct _GtrViewPrivate
 {
+  GSettings *editor_settings;
+  GSettings *ui_settings;
+
   GtkSourceBuffer *buffer;
 
   guint search_flags;
@@ -97,11 +100,15 @@ gtr_view_init (GtrView * view)
   GPtrArray *dirs;
   gchar **langs;
   const gchar *const *temp;
-  gchar *datadir;
+  gchar *ui_dir;
+  GtrViewPrivate *priv;
 
   view->priv = GTR_VIEW_GET_PRIVATE (view);
 
-  GtrViewPrivate *priv = view->priv;
+  priv = view->priv;
+
+  priv->editor_settings = g_settings_new ("org.gnome.gtranslator.preferences.editor");
+  priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
 
   lm = gtk_source_language_manager_new ();
   dirs = g_ptr_array_new ();
@@ -110,9 +117,8 @@ gtr_view_init (GtrView * view)
        temp != NULL && *temp != NULL; ++temp)
     g_ptr_array_add (dirs, g_strdup (*temp));
 
-  datadir = gtr_dirs_get_gtr_data_dir ();
-  /* FIXME: Where pkgdatadir must be free */
-  g_ptr_array_add (dirs, datadir);
+  ui_dir = g_build_filename (gtr_dirs_get_gtr_data_dir (), "ui", NULL);
+  g_ptr_array_add (dirs, ui_dir);
   g_ptr_array_add (dirs, NULL);
   langs = (gchar **) g_ptr_array_free (dirs, FALSE);
 
@@ -126,24 +132,23 @@ gtr_view_init (GtrView * view)
                             GTK_TEXT_BUFFER (priv->buffer));
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (view), GTK_WRAP_WORD);
 
-  //Set syntax highlight according to preferences
+  /* Set syntax highlight according to preferences */
   gtk_source_buffer_set_highlight_syntax (priv->buffer,
-                                          gtr_prefs_manager_get_highlight_syntax
-                                          ());
+                                          g_settings_get_boolean (priv->editor_settings,
+                                                                  GTR_SETTINGS_HIGHLIGHT_SYNTAX));
 
-  //Set dot char according to preferences
+  /* Set dot char according to preferences */
+  gtr_view_enable_visible_whitespace (view,
+                                      g_settings_get_boolean (priv->editor_settings,
+                                                              GTR_SETTINGS_VISIBLE_WHITESPACE));
 
-  if (gtr_prefs_manager_get_visible_whitespace ())
-    gtr_view_enable_visible_whitespace (view, TRUE);
-
-  /*
-   *  Set fonts according to preferences 
-   */
-  if (gtr_prefs_manager_get_use_custom_font ())
+  /* Set fonts according to preferences */
+  if (g_settings_get_boolean (priv->editor_settings, GTR_SETTINGS_USE_CUSTOM_FONT))
     {
       gchar *editor_font;
 
-      editor_font = g_strdup (gtr_prefs_manager_get_editor_font ());
+      editor_font = g_settings_get_string (priv->editor_settings,
+                                           GTR_SETTINGS_EDITOR_FONT);
 
       gtr_view_set_font (view, FALSE, editor_font);
 
@@ -154,16 +159,28 @@ gtr_view_init (GtrView * view)
       gtr_view_set_font (view, TRUE, NULL);
     }
 
-  /*
-   * Set scheme color according to preferences
-   */
+  /* Set scheme color according to preferences */
   gtr_view_reload_scheme_color (view);
 }
 
 static void
-gtr_view_finalize (GObject * object)
+gtr_view_dispose (GObject * object)
 {
-  G_OBJECT_CLASS (gtr_view_parent_class)->finalize (object);
+  GtrView *view = GTR_VIEW (object);
+
+  if (view->priv->editor_settings)
+    {
+      g_object_unref (view->priv->editor_settings);
+      view->priv->editor_settings = NULL;
+    }
+
+  if (view->priv->ui_settings)
+    {
+      g_object_unref (view->priv->ui_settings);
+      view->priv->ui_settings = NULL;
+    }
+
+  G_OBJECT_CLASS (gtr_view_parent_class)->dispose (object);
 }
 
 static void
@@ -173,7 +190,7 @@ gtr_view_class_init (GtrViewClass * klass)
 
   g_type_class_add_private (klass, sizeof (GtrViewPrivate));
 
-  object_class->finalize = gtr_view_finalize;
+  object_class->dispose = gtr_view_dispose;
 }
 
 /**
@@ -382,11 +399,21 @@ gtr_view_set_font (GtrView * view, gboolean def, const gchar * font_name)
   g_return_if_fail (GTR_IS_VIEW (view));
 
   if (def)
-    font_name = g_strdup ("Sans 10");
+    {
+      GSettings *gtr_settings;
+      gchar *font;
 
-  g_return_if_fail (font_name != NULL);
+      gtr_settings = _gtr_application_get_settings (GTR_APP);
+      font = gtr_settings_get_system_font (GTR_SETTINGS (gtr_settings));
+
+      font_desc = pango_font_description_from_string (font);
+      g_free (font);
+    }
+  else
+    {
+      font_desc = pango_font_description_from_string (font_name);
+    }
 
-  font_desc = pango_font_description_from_string (font_name);
   g_return_if_fail (font_desc != NULL);
 
   gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
@@ -406,29 +433,23 @@ gtr_view_set_font (GtrView * view, gboolean def, const gchar * font_name)
 void
 gtr_view_set_search_text (GtrView * view, const gchar * text, guint flags)
 {
-  GtkSourceBuffer *doc;
   gchar *converted_text;
-  gboolean notify = FALSE;
-  //gboolean update_to_search_region = FALSE;
 
   g_return_if_fail (GTR_IS_VIEW (view));
   g_return_if_fail ((text == NULL) || (view->priv->search_text != text));
   g_return_if_fail ((text == NULL) || g_utf8_validate (text, -1, NULL));
 
   //gedit_debug_message (DEBUG_DOCUMENT, "text = %s", text);
-  doc = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
 
   if (text != NULL)
     {
       if (*text != '\0')
         {
           converted_text = gtr_utils_unescape_search_text (text);
-          notify = !gtr_view_get_can_search_again (view);
         }
       else
         {
           converted_text = g_strdup ("");
-          notify = gtr_view_get_can_search_again (view);
         }
 
       g_free (view->priv->search_text);
@@ -522,7 +543,7 @@ gtr_view_search_forward (GtrView * view,
 {
   GtkSourceBuffer *doc;
   GtkTextIter iter;
-  GtkSourceSearchFlags search_flags;
+  GtkTextSearchFlags search_flags;
   gboolean found = FALSE;
   GtkTextIter m_start;
   GtkTextIter m_end;
@@ -551,19 +572,19 @@ gtr_view_search_forward (GtrView * view,
   else
     iter = *start;
 
-  search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+  search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
   if (!GTR_SEARCH_IS_CASE_SENSITIVE (view->priv->search_flags))
     {
-      search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+      search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
     }
 
   while (!found)
     {
-      found = gtk_source_iter_forward_search (&iter,
-                                              view->priv->search_text,
-                                              search_flags,
-                                              &m_start, &m_end, end);
+      found = gtk_text_iter_forward_search (&iter,
+                                            view->priv->search_text,
+                                            search_flags,
+                                            &m_start, &m_end, end);
 
       if (found && GTR_SEARCH_IS_ENTIRE_WORD (view->priv->search_flags))
         {
@@ -610,7 +631,7 @@ gtr_view_search_backward (GtrView * view,
 {
   GtkSourceBuffer *doc;
   GtkTextIter iter;
-  GtkSourceSearchFlags search_flags;
+  GtkTextSearchFlags search_flags;
   gboolean found = FALSE;
   GtkTextIter m_start;
   GtkTextIter m_end;
@@ -639,19 +660,19 @@ gtr_view_search_backward (GtrView * view,
   else
     iter = *end;
 
-  search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+  search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
   if (!GTR_SEARCH_IS_CASE_SENSITIVE (view->priv->search_flags))
     {
-      search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+      search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
     }
 
   while (!found)
     {
-      found = gtk_source_iter_backward_search (&iter,
-                                               view->priv->search_text,
-                                               search_flags,
-                                               &m_start, &m_end, start);
+      found = gtk_text_iter_backward_search (&iter,
+                                             view->priv->search_text,
+                                             search_flags,
+                                             &m_start, &m_end, start);
 
       if (found && GTR_SEARCH_IS_ENTIRE_WORD (view->priv->search_flags))
         {
@@ -693,7 +714,7 @@ gtr_view_replace_all (GtrView * view,
   GtkTextIter iter;
   GtkTextIter m_start;
   GtkTextIter m_end;
-  GtkSourceSearchFlags search_flags = 0;
+  GtkTextSearchFlags search_flags = 0;
   gboolean found = TRUE;
   gint cont = 0;
   gchar *search_text;
@@ -718,11 +739,11 @@ gtr_view_replace_all (GtrView * view,
 
   gtk_text_buffer_get_start_iter (buffer, &iter);
 
-  search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
+  search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
 
   if (!GTR_SEARCH_IS_CASE_SENSITIVE (flags))
     {
-      search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+      search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
     }
 
   replace_text_len = strlen (replace_text);
@@ -737,10 +758,10 @@ gtr_view_replace_all (GtrView * view,
 
   do
     {
-      found = gtk_source_iter_forward_search (&iter,
-                                              search_text,
-                                              search_flags,
-                                              &m_start, &m_end, NULL);
+      found = gtk_text_iter_forward_search (&iter,
+                                            search_text,
+                                            search_flags,
+                                            &m_start, &m_end, NULL);
 
       if (found && GTR_SEARCH_IS_ENTIRE_WORD (flags))
         {
@@ -797,13 +818,15 @@ gtr_view_reload_scheme_color (GtrView * view)
   GtkSourceBuffer *buf;
   GtkSourceStyleScheme *scheme;
   GtkSourceStyleSchemeManager *manager;
-  const gchar *scheme_id;
+  gchar *scheme_id;
 
   buf = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
   manager = gtk_source_style_scheme_manager_get_default ();
 
-  scheme_id = gtr_prefs_manager_get_color_scheme ();
+  scheme_id = g_settings_get_string (view->priv->ui_settings,
+                                     GTR_SETTINGS_COLOR_SCHEME);
   scheme = gtk_source_style_scheme_manager_get_scheme (manager, scheme_id);
+  g_free (scheme_id);
 
   gtk_source_buffer_set_style_scheme (buf, scheme);
 }
