@@ -115,7 +115,7 @@ on_activate_item_cb (GtkMenuItem * menuitem,
 }
 
 static void
-free_list (gpointer data, gpointer useless)
+free_match (gpointer data)
 {
   GtrTranslationMemoryMatch *match = (GtrTranslationMemoryMatch *) data;
 
@@ -197,7 +197,7 @@ showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrTranslationMemoryUi * tm_ui)
 
       gtk_list_store_append (model, &iter);
       gtk_list_store_set (model, &iter,
-                          SHORTCUT_COLUMN, GDK_0 + k,
+                          SHORTCUT_COLUMN, GDK_KEY_0 + k,
                           STRING_COLUMN, match->match,
                           LEVEL_COLUMN, match->level,
                           -1);
@@ -234,7 +234,7 @@ showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrTranslationMemoryUi * tm_ui)
                          item_name);
 
       gtk_menu_item_set_accel_path (GTK_MENU_ITEM (tm_item), accel_path);
-      gtk_accel_map_add_entry (accel_path, GDK_0 + (j - 1), GDK_CONTROL_MASK);
+      gtk_accel_map_add_entry (accel_path, GDK_KEY_0 + (j - 1), GDK_CONTROL_MASK);
 
       g_free (accel_path);
       g_free (item_name);
@@ -253,9 +253,7 @@ showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrTranslationMemoryUi * tm_ui)
 
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (tm_menu), items_menu);
 
-  /* Freeing the list */
-  g_list_foreach (tm_list, (GFunc) free_list, NULL);
-  g_list_free (tm_list);
+  g_list_free_full (tm_list, free_match);
 }
 
 static void
